from setuptools import setup, find_packages

setup(
    name="kd-ar-stream",
    version="1.0.0",
    packages=find_packages(),
    include_package_data=True,  # Paketle birlikte veri dosyalarını da ekle
    package_data={
        "kd_ar_stream": ["data/*.txt"]
    },
    install_requires=[
        "numpy>=1.24.0",
        "scipy>=1.11.0",
        "matplotlib>=3.7.0"
    ],
    python_requires=">=3.10",
    description="KD-AR Stream: Real-Time Data Stream Clustering with Adaptive Radius",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/senolali/kd-ar-stream",
    author="Ali Şenol",
    author_email="alisenol@tarsus.edu.tr",
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



# kd_ar_stream/utils.py
import numpy as np
from importlib.resources import files

def load_exclastar():
    """Load ExclaStar dataset from the package."""
    data_path = files("kd_ar_stream").joinpath("data/ExclaStar.txt")
    dataset = np.loadtxt(data_path, delimiter=',', dtype=float)
    X = dataset[:, 1:3]
    y_true = dataset[:, 3]
    return X, y_true
